### v2.1.1
##### Date：2023/03/01
##### Notes：
- Clean up example program

### v2.1.0
##### Date：2022/12/22
##### Notes：
- Add debug model in TE

### v2.0.0
##### Date：2022/08/03
##### Notes：
- Add test cases

### v1.8.0
##### Date：2022/04/26
##### Notes：
- Supports First Event


### v1.7.0
##### Date：2021/12/29
##### Notes：
- Added support for complex structure types


### v1.6.2
##### Date：2021/08/05
##### Notes：
- Fix the problem that the flush method does not refresh the file date


### v1.6.1
##### Date：2021/06/04
##### Notes：
- Modify LoggingConsumer's default write file condition to write 5 pieces of data once
- Modify the default maximum buffer limit of BatchConsumer to 50 batches


### v1.6.0
##### Date：2021/03/22
##### Notes：
- Added network failure retry mechanism
- Increase the buffer area, retry 3 times to send failed data will be stored in the buffer area, the cache data exceeds the upper limit will discard the early data
- Support #app_id attribute